Learn R Programming

rioplot (version 1.1.1)

GSS2018: Subset of the General Social Survey analyzed by Schoon, Melamed, and Breiger (2024)

Description

Subset of the General Social Survey analyzed by Schoon, Melamed, and Breiger (2024). Full details on the variable selection and source information is available therein.

Usage

data("GSS2018")

Arguments

Format

A data frame with 558 observations on the following 7 variables.

dog

a numeric vector

race

a numeric vector

sex

a numeric vector

children

a numeric vector

married

a numeric vector

age

a numeric vector

income

a numeric vector

References

Schoon, Eric W., David Melamed, and Ronald L. Breiger. 2024. Regression Inside Out. NY: Cambridge University Press.

Examples

Run this code
data(GSS2018)
head(GSS2018)

Run the code above in your browser using DataLab