Learn R Programming

rioplot (version 1.1.1)

Kenworthy99: Data to replicate OLS regression models reported in Kenworthy (1999).

Description

Data to replicate OLS regression models reported in Kenworthy (1999). Data were analyzed in Schoon, Melamed, and Breiger (2024). Full details on the variable selection and source information is available therein.

Usage

data("Kenworthy99")

Arguments

Format

A data frame with 15 observations on the following 6 variables.

dv

a numeric vector

gdp

a numeric vector

pov

a numeric vector

tran

a numeric vector

ISO3

a character vector

nation.long

a character vector

References

Kenworthy, Lane. 1999. "Do social-welfare policies reduce poverty? A cross-national assessment."" Social Forces 77(3): 1119-1139. Schoon, Eric W., David Melamed, and Ronald L. Breiger. 2024. Regression Inside Out. NY: Cambridge University Press.

Examples

Run this code
data(Kenworthy99)
head(Kenworthy99)

Run the code above in your browser using DataLab